#!/bin/sh 

DB_DIR=/opt/cluster/db
DB_NAME=noctua.db
DB=${DB_DIR}/${DB_NAME}
CFG=/etc/sysconfig/cluster/db.cf

check_operating_system() {
    # group has to be idg since package-server has to be able to write there
    if [ -f /etc/debian_version ] ; then
        # debian
        DIST_TYPE="debian"
        WWW_USER=www-data
        WWW_GROUP=idg
    elif [ -f /etc/SUSE-brand ] ; then
        # suse
        DIST_TYPE="suse"
        WWW_USER=wwwrun
        WWW_GROUP=idg
    else
        # redhat / centos
        DIST_TYPE="centos"
        WWW_USER=apache
        WWW_GROUP=idg
    fi
}

set_permissions() {
    if [ ! -d ${DB_DIR} ]; then
        mkdir ${DB_DIR}
    fi
    chown -Rf ${WWW_USER}:idg ${DB_DIR}
    chmod 770 ${DB_DIR}
    chmod -Rf 777 /opt/cluster/etc/uwsgi
}

backup_existing_config() {
    if [ -f ${CFG} ] ; then
        CFG_BU="${CFG}_$(date | tr -s ' ' '_')"
        echo "creating backup of db-cfg ${CFG_BU}"
        cp -a ${CFG} ${CFG_BU}
        # stop all tasks
        /opt/cluster/sbin/icsw service stop
    fi
}

setup_cluster () {
    /opt/cluster/sbin/icsw setup --clear-migrations --db-file-owner ${WWW_USER} --db-file-group ${WWW_GROUP} --db-file-mode 660  --db-path ${DB_DIR} --database ${DB_NAME} --engine sqlite
    /opt/python-init/lib/python2.7/site-packages/initat/cluster/manage.py create_noctua_fixtures
    #/opt/cluster/sbin/setup_cluster.py --enable-auto-update
}

set_firewall_config() {
    if [ -e /usr/sbin/ucr ] ; then 
        ucr set security/packetfilter/tcp/18080/all=ACCEPT
        /etc/security/packetfilter.d/10_univention-firewall_start.sh                
        echo "
        RewriteEngine On
        RewriteRule ^/noctua$ /noctua/ [R]
        RewriteRule ^/icinga$ /icinga/ [R]
        ProxyRequests off
        ProxyPass /noctua/ http://127.0.0.1:18080/cluster/
        ProxyPassReverse /noctua/ http://127.0.0.1:18080/cluster/
        ProxyPassMatch ^/cluster/(.*)\$ http://127.0.0.1:18080/cluster/\$1
        ProxyPass /icinga/ http://127.0.0.1:18080/icinga/
        ProxyPassReverse /icinga/ http://127.0.0.1:18080/icinga/
" > /etc/apache2/conf.d/init-noctua
        service apache2 reload
    fi
}

copy_rewrite () {
    # copy and rewrite localhost.conf_sample
    cat /etc/nginx/sites-enabled/localhost.conf_sample | sed "s/listen.*80/listen 18080/" > /etc/nginx/sites-enabled/localhost.conf
}

# enable rrd-graphing
write_xml_file() {
    echo '<?xml version="1.0" encoding="ASCII"?>
        <mv_targets>
          <mv_target target="localhost" send_every="30" enabled="1" port="8002" send_name="" full_info_every="10" immediate="1"/>
        </mv_targets>
' > /etc/sysconfig/host-monitoring.d/machvector.xml
}

restart_services() {
    /opt/cluster/sbin/icsw service restart
    /opt/cluster/bin/send_command_zmq.py -H localhost -p 8010 rebuild_host_config
}

set_process_number () {
    sed -i s/processes=8/processes=2/g /opt/cluster/etc/uwsgi/webfrontend-common.include
    sed -i s/workers=8/workers=2/g /opt/cluster/etc/uwsgi/webfrontend-common.include
}

setup_test_license () {
    if [ -e /usr/sbin/ucr ] ; then
        /opt/cluster/sbin/icsw license register_cluster -u univention -p univention -n "$(hostname)"
        if [ $? -ne 0 ]; then
            echo >&2 "Failed to obtain a license from init.at."
            echo >&2
            echo >&2 "Please ensure that you have a working internet connection and run the following command:"
            echo >&2 "/opt/cluster/sbin/icsw license register_cluster -u univention -p univention -n univention"
            echo >&2 "If you do not have a working internet connection, please contact noctua@init.at ."
            return 1
        fi
    fi
    return 0
}

run_collectstatic () {
    echo "collecting static files"
    /opt/python-init/lib/python2.7/site-packages/initat/cluster/manage.py collectstatic --noinput -c > /dev/null
}


set_process_number
check_operating_system

# handle_existing_database
if [ -f ${DB} ]; then
    echo "Existing database found, using it ..."
else
    echo "No existing database found, continue installation ..."
    set_permissions
    backup_existing_config
    setup_cluster
    copy_rewrite
    write_xml_file
    restart_services
    # this is necessary on first install since icsw-server doesn't call it if db.cf does not exist  # June 2015
    run_collectstatic
fi
# we also need to obtain a license for ucs installations which have existed before we had licenses
setup_test_license
SETUP_LICENSE_RETURN_VALUE=$?
set_firewall_config

exit $SETUP_LICENSE_RETURN_VALUE
